[![License](https://img.shields.io/github/license/Willcox-Research-Group/rom-operator-inference-python3)](./LICENSE)
[![Top language](https://img.shields.io/github/languages/top/Willcox-Research-Group/rom-operator-inference-python3)](https://www.python.org)
![Code size](https://img.shields.io/github/languages/code-size/Willcox-Research-Group/rom-operator-inference-python3)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://black.readthedocs.io/en/stable/)
[![Issues](https://img.shields.io/github/issues/Willcox-Research-Group/rom-operator-inference-python3)](https://github.com/Willcox-Research-Group/rom-operator-inference-python3/issues)
[![Latest commit](https://img.shields.io/github/last-commit/Willcox-Research-Group/rom-operator-inference-python3)](https://github.com/Willcox-Research-Group/rom-operator-inference-python3/commits/main)
[![PyPI](https://img.shields.io/pypi/wheel/opinf)](https://pypi.org/project/opinf/)
[![Documentation](https://img.shields.io/badge/Documentation-important)](https://Willcox-Research-Group.github.io/rom-operator-inference-Python3/)

# Operator Inference in Python

This is a Python implementation of Operator Inference for learning projection-based polynomial reduced-order models of dynamical systems.
The procedure is **data-driven** and **non-intrusive**, making it a viable candidate for model reduction of "glass-box" systems.
The methodology was [introduced in 2016 by Peherstorfer and Willcox](https://www.sciencedirect.com/science/article/pii/S0045782516301104).

[**See the Documentation Here**](https://Willcox-Research-Group.github.io/rom-operator-inference-Python3/).

---

**Contributors**:
[Shane McQuarrie](https://github.com/shanemcq18),
[Renee Swischuk](https://github.com/swischuk),
[Elizabeth Qian](https://github.com/elizqian),
[Boris Kramer](http://kramer.ucsd.edu/),
[Karen Willcox](https://kiwi.oden.utexas.edu/).
